@@ -6,8 +6,8 @@ Description:
     General classes to represent a structured (scientific) document.
 '''
 
-import nltk
-
+#from nltk import word_tokenize
+from nltk.tokenize import word_tokenize
 
 ##################################################################
 # NODE SUPER CLASS
@@ -142,7 +142,7 @@ class Node(object):
 
     def words(self, recursive=True, ignore_floats=True):
         words = list()
-        words.extend(nltk.word_tokenize(self.text))
+        words.extend(word_tokenize(self.text))
         for c in self._children:
             if c.is_section() and recursive:
                 words.extend(c.words(True, ignore_floats))
@@ -157,7 +157,7 @@ class Node(object):
             return list()
         full_text = self.raw(recursive, ignore_floats)
         sents = tokenizer.tokenize(full_text)
-        return [nltk.word_tokenize(s) for s in sents]
+        return [word_tokenize(s) for s in sents]
 
     def __unicode__(self):
         return "Node(children=%s)" % unicode(self._children)
